@@ -1,4 +1,4 @@
-//@line 41 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.ELsmp_Depend/mozilla/browser/base/content/openLocation.js"
+//@line 41 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/base/content/openLocation.js"
 
 var browser;
 var dialog = {};
@@ -62,18 +62,21 @@ function open()
     url = dialog.input.value;
 
   try {
+    // Whichever target we use for the load, we allow third-party services to
+    // fixup the URI
     switch (dialog.openWhereList.value) {
       case "0":
-        browser.loadURI(url, null, postData.value);
+        browser.loadURI(url, null, postData.value, true);
         break;
       case "1":
-        window.opener.delayedOpenWindow(getBrowserURL(), "all,dialog=no", url, postData);
+        window.opener.delayedOpenWindow(getBrowserURL(), "all,dialog=no",
+                                        url, postData.value, null, null, true);
         break;
       case "3":
         if (browser.getBrowser && browser.getBrowser().localName == "tabbrowser")
-          browser.delayedOpenTab(url, null, null, postData.value);
+          browser.delayedOpenTab(url, null, null, postData.value, true);
         else
-          browser.loadURI(url, null, postData.value); // Just do a normal load.
+          browser.loadURI(url, null, postData.value, true); // Just do a normal load.
         break;
     }
   }
