@@ -70,6 +70,11 @@ FeedConverter.prototype = {
    * docshell for the load.
    */
   _listener: null,
+
+  /**
+   * Records if the feed was sniffed
+   */
+  _sniffed: false,
   
   /**
    * See nsIStreamConverter.idl
@@ -185,7 +190,11 @@ FeedConverter.prototype = {
            Cc["@mozilla.org/network/io-service;1"].
            getService(Ci.nsIIOService);
       var chromeChannel;
-      if (result.doc) {
+
+      // show the feed page if it wasn't sniffed and we have a document,
+      // or we have a document, title, and link or id
+      if (result.doc && (!this._sniffed ||
+          (result.doc.title && (result.doc.link || result.doc.id)))) {
         // If there was no automatic handler, or this was a podcast,
         // photostream or some other kind of application, we must always
         // show the preview page...
@@ -202,6 +211,7 @@ FeedConverter.prototype = {
       else
         chromeChannel = ios.newChannelFromURI(result.uri, null);
 
+      chromeChannel.loadGroup = this._request.loadGroup;
       chromeChannel.asyncOpen(this._listener, null);
     }
     finally {
@@ -223,6 +233,17 @@ FeedConverter.prototype = {
    */
   onStartRequest: function FC_onStartRequest(request, context) {
     var channel = request.QueryInterface(Ci.nsIChannel);
+
+    // Check for a header that tells us there was no sniffing
+    // The value doesn't matter.
+    try {
+      var httpChannel = channel.QueryInterface(Ci.nsIHttpChannel);
+      var noSniff = httpChannel.getResponseHeader("X-Moz-Is-Feed");
+    }
+    catch (ex) {
+      this._sniffed = true;
+    }
+
     this._request = request;
     
     // Save and reset the forced state bit early, in case there's some kind of
@@ -233,7 +254,6 @@ FeedConverter.prototype = {
     this._forcePreviewPage = feedService.forcePreviewPage;
     feedService.forcePreviewPage = false;
 
-
     // Parse feed data as it comes in
     this._processor =
         Cc["@mozilla.org/feed-processor;1"].
@@ -313,7 +333,7 @@ var FeedResultService = {
     case "client":
       var clientApp = 
         prefs.getComplexValue(PREF_SELECTED_APP, Ci.nsILocalFile);
-//@line 373 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedConverter.js"
+//@line 393 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedConverter.js"
       var ss = 
           Cc["@mozilla.org/browser/shell-service;1"].
           getService(Ci.nsIShellService_MOZILLA_1_8_BRANCH);
@@ -329,9 +349,9 @@ var FeedResultService = {
           Cc["@mozilla.org/appshell/window-mediator;1"].
           getService(Ci.nsIWindowMediator);
       var topWindow = wm.getMostRecentWindow("navigator:browser");
-//@line 391 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedConverter.js"
+//@line 411 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedConverter.js"
       topWindow.FeedHandler.addLiveBookmark(spec, title, subtitle);
-//@line 393 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedConverter.js"
+//@line 413 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedConverter.js"
       break;
     }
   },
@@ -454,7 +474,10 @@ FeedProtocolHandler.prototype = {
     else
       uri.scheme = "http";
 
-    var channel = ios.newChannelFromURI(uri, null);
+    var channel =
+      ios.newChannelFromURI(uri, null).QueryInterface(Ci.nsIHttpChannel);
+    // Set this so we know this is supposed to be a feed
+    channel.setRequestHeader("X-Moz-Is-Feed", "1", false);
     channel.originalURI = uri;
     return channel;
   },
@@ -550,39 +573,12 @@ function NS_ASSERT(condition, message) {
   if (condition)
     return;
 
-  var caller = arguments.callee.caller;
   var assertionText = "ASSERT: " + message + "\n";
-  dump(assertionText);
 
-  var stackText = "";
-  if (gTraceOnAssert) {
-    stackText = "Stack Trace: \n";
-    var count = 0;
-    while (caller) {
-      stackText += count++ + ":" + caller.name + "(";
-      for (var i = 0; i < caller.arguments.length; ++i) {
-        var arg = caller.arguments[i];
-        stackText += arg;
-        if (i < caller.arguments.length - 1)
-          stackText += ",";
-      }
-      stackText += ")\n";
-      caller = caller.arguments.callee.caller;
-    }
-  }
-
-  var environment = Components.classes["@mozilla.org/process/environment;1"].
-                    getService(Components.interfaces.nsIEnvironment);
-  if (environment.exists("XUL_ASSERT_PROMPT") &&
-      !parseInt(environment.get("XUL_ASSERT_PROMPT")))
-    return;
-
-  var source = null;
-  if (this.window)
-    source = window;
-  var ps = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].
-           getService(Components.interfaces.nsIPromptService);
-  ps.alert(source, "Assertion Failed", assertionText + stackText);
+//@line 72 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
+  Components.util.reportError(assertionText);
+  return;
+//@line 108 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
 }
 //@line 37 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/GenericFactory.js"
 
