@@ -189,7 +189,7 @@ FeedWriter.prototype = {
    */
   _setTitleImage: function FW__setTitleImage(container) {
     try {
-      var parts = this._getPropertyAsBag(container, "image");
+      var parts = container.image;
       
       // Set up the title image (supplied by the feed)
       var feedTitleImage = this._document.getElementById("feedTitleImage");
@@ -248,7 +248,7 @@ FeedWriter.prototype = {
         entryContainer.appendChild(title);
       }
 
-      var body = this._document.createElementNS(HTML_NS, "p");
+      var body = this._document.createElementNS(HTML_NS, "div");
       var summary = entry.summary || entry.content;
       var docFragment = null;
       if (summary) {
@@ -258,7 +258,8 @@ FeedWriter.prototype = {
         else
           LOG("no base?");
         docFragment = summary.createDocumentFragment(body);
-        body.appendChild(docFragment);
+        if (docFragment)
+          body.appendChild(docFragment);
 
         // If the entry doesn't have a title, append a # permalink
         // See http://scripting.com/rss.xml for an example
@@ -274,6 +275,9 @@ FeedWriter.prototype = {
       body.className = "feedEntryContent";
       entryContainer.appendChild(body);
       feedContent.appendChild(entryContainer);
+      var clearDiv = this._document.createElementNS(HTML_NS, "div");
+      clearDiv.style.clear = "both";
+      feedContent.appendChild(clearDiv);
     }
   },
   
@@ -326,7 +330,7 @@ FeedWriter.prototype = {
    * @returns The display name of the application represented by the file.
    */
   _getFileDisplayName: function FW__getFileDisplayName(file) {
-//@line 398 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 402 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
     var ios = 
         Cc["@mozilla.org/network/io-service;1"].
         getService(Ci.nsIIOService);
@@ -387,9 +391,9 @@ FeedWriter.prototype = {
           // XXXben - we need to compare this with the running instance executable
           //          just don't know how to do that via script...
           // XXXmano TBD: can probably add this to nsIShellService
-//@line 464 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 468 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
           if (fp.file.leafName != "firefox-bin") {
-//@line 467 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 471 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
             var selectedAppMenuItem = this.selectedApplicationItemWrapped;
             this._initMenuItemWithFile(selectedAppMenuItem, selectedApp);
 
@@ -526,7 +530,7 @@ FeedWriter.prototype = {
             selectedAppMenuItem.hidden = false;
             selectedAppMenuItem.doCommand();
 
-//@line 612 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 616 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
             break;
           }
         }
@@ -576,7 +580,7 @@ FeedWriter.prototype = {
       selectedApplicationItem.hidden = true;
     }
 
-//@line 707 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 711 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
 
     // "Choose Application..." menuitem
     menuItem = this._document.createElementNS(XUL_NS, "menuitem");
@@ -793,7 +797,7 @@ FeedWriter.prototype = {
           prefs.setComplexValue(PREF_SELECTED_APP, Ci.nsILocalFile, 
                                 this.selectedApplicationItemWrapped.file);
           break;
-//@line 930 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 934 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
         case "liveBookmarksMenuItem":
           defaultHandler = "bookmarks";
           prefs.setCharPref(PREF_SELECTED_READER, "bookmarks");
