@@ -55,6 +55,9 @@ function nsPluginInstallerWizard(){
   // array holding pids of plugins that require a license
   this.mPluginLicenseArray = new Array();
 
+  // how many plugins are to be installed
+  this.pluginsToInstallNum = 0;
+
   this.mTab = null;
   this.mSuccessfullPluginInstallation = 0;
 
@@ -134,6 +137,8 @@ nsPluginInstallerWizard.prototype.showPluginList = function (){
   for (var run = myPluginList.childNodes.length; run > 0; run--)
     myPluginList.removeChild(myPluginList.childNodes.item(run));
 
+  this.pluginsToInstallNum = 0;
+
   for (pluginInfoItem in this.mPluginInfoArray){
     // [plugin image] [Plugin_Name Plugin_Version]
 
@@ -151,6 +156,9 @@ nsPluginInstallerWizard.prototype.showPluginList = function (){
 
     if (pluginInfo.InstallerShowsUI == "true")
       hasPluginWithInstallerUI = true;
+
+    // keep a running count of plugins the user wants to install
+    this.pluginsToInstallNum++;
   }
 
   if (hasPluginWithInstallerUI)
@@ -163,14 +171,14 @@ nsPluginInstallerWizard.prototype.showPluginList = function (){
 nsPluginInstallerWizard.prototype.toggleInstallPlugin = function (aPid, aCheckbox) {
   this.mPluginInfoArray[aPid].toBeInstalled = aCheckbox.checked;
 
-  // if no plugins are checked, don't allow to advance  
-  var pluginsToInstallNum = 0;
+  // if no plugins are checked, don't allow to advance
+  this.pluginsToInstallNum = 0;
   for (pluginInfoItem in this.mPluginInfoArray){
     if (this.mPluginInfoArray[pluginInfoItem].toBeInstalled)
-      pluginsToInstallNum++;
+      this.pluginsToInstallNum++;
   }
 
-  if (pluginsToInstallNum > 0)
+  if (this.pluginsToInstallNum > 0)
     this.canAdvance(true);
   else
     this.canAdvance(false);
@@ -218,7 +226,11 @@ nsPluginInstallerWizard.prototype.showLicenses = function (){
 }
 
 nsPluginInstallerWizard.prototype.enableNext = function (){
-  gPluginInstaller.canAdvance(true);
+  // if only one plugin exists, don't enable the next button until
+  // the license is accepted
+  if (gPluginInstaller.pluginsToInstallNum > 1)
+    gPluginInstaller.canAdvance(true);
+
   document.getElementById("licenseRadioGroup1").disabled = false;
   document.getElementById("licenseRadioGroup2").disabled = false;
 }
@@ -306,6 +318,12 @@ nsPluginInstallerWizard.prototype.storeLicenseRadioGroup = function (){
   pluginInfo.licenseAccepted = !document.getElementById("licenseRadioGroup").selectedIndex;
 }
 
+nsPluginInstallerWizard.prototype.licenseRadioGroupChange = function(aAccepted) {
+  // only if one plugin is to be installed should selection change the next button
+  if (this.pluginsToInstallNum == 1)
+    this.canAdvance(aAccepted);
+}
+
 nsPluginInstallerWizard.prototype.advancePage = function (aPageId, aCanAdvance, aCanRewind, aCanCancel){
   this.canAdvance(true);
   document.getElementById("plugin-installer-wizard").advance(aPageId);
@@ -503,14 +521,14 @@ nsPluginInstallerWizard.prototype.showPluginResults = function (){
     var pluginRequest = this.mPluginRequestArray[pluginInfoItem];
 
     // if there is a pluginspage, show UI
-    if (pluginRequest && pluginRequest.pluginsPage) {
+    if (pluginRequest) {
       this.addPluginResultRow(
           "",
-          this.getString("pluginInstallation.unknownPlugin"),
-          pluginInfoItem,
+          this.getFormattedString("pluginInstallation.unknownPlugin", [pluginInfoItem]),
           null,
           null,
-          this.mPluginRequestArray[pluginInfoItem].pluginsPage);
+          null,
+          pluginRequest.pluginsPage);
     }
 
     notInstalledList += "&mimetype=" + pluginInfoItem;
@@ -628,7 +646,7 @@ function wizardFinish(){
     // clear the tab's plugin list only if we installed at least one plugin
     gPluginInstaller.mTab.missingPlugins = null;
     // reset UI
-    window.opener.getBrowser().hideMessage(window.opener.getBrowser().selectedBrowser, "top");
+    window.opener.gMissingPluginInstaller.closeNotification();
     // reload the browser to make the new plugin show
     window.opener.getBrowser().reloadTab(gPluginInstaller.mTab);
   }
